@@ -3,9 +3,10 @@
 import argparse
 import math
 import multiprocessing as mp
-import os
 import subprocess
 import sys
+from pathlib import Path
+from typing import Generator
 
 from wpiformat.bracecomment import BraceComment
 from wpiformat.cidentlist import CIdentList
@@ -27,19 +28,17 @@ from wpiformat.usingnamespacestd import UsingNamespaceStd
 from wpiformat.whitespace import Whitespace
 
 
-def filter_ignored_files(names):
+def filter_for_unignored_files(filenames: list[Path]) -> list[Path]:
     """Returns list of files not in .gitignore.
 
     Keyword arguments:
-    names -- list of files to filter
+    filenames -- list of filenames to filter
     """
     # "git check-ignore" misbehaves when the names are separated by "\r\n" on
     # Windows, so os.linesep isn't used here.
-    encoded_names = "\n".join(names).encode()
-
     proc = subprocess.run(
         ["git", "check-ignore", "--no-index", "-n", "-v", "--stdin"],
-        input=encoded_names,
+        input="\n".join(f.as_posix() for f in filenames).encode(),
         stdout=subprocess.PIPE,
     )
     if proc.returncode == 128:
@@ -47,15 +46,13 @@ def filter_ignored_files(names):
             proc.returncode, proc.args, proc.stdout, proc.stderr
         )
 
-    output_list = proc.stdout.decode().split("\n")
-
     # "git check-ignore" prefixes the names of non-ignored files with "::",
     # wraps names in quotes on Windows, and outputs "\n" line separators on all
     # platforms.
     return [
-        name[2:].lstrip().strip('"').replace("\\\\", "\\")
-        for name in output_list
-        if name[0:2] == "::"
+        Path(filename[2:].lstrip().strip('"').replace("\\\\", "\\"))
+        for filename in proc.stdout.decode().split("\n")
+        if filename[0:2] == "::"
     ]
 
 
@@ -78,77 +75,84 @@ def proc_init(task_pipeline_copy, verbose1_copy, verbose2_copy):
     print_lock = mp.Lock()
 
 
-def proc_pipeline(name):
+def proc_pipeline(filename: Path) -> bool:
     """Runs the contents of each file through the task pipeline.
 
     If the contents were modified at any point, the result is written back out
     to the file.
 
     Keyword arguments:
-    name -- file name string
+    filename -- filename
     """
-    config_file = Config(os.path.dirname(name), ".styleguide")
+    # TODO: Remove handling for deprecated .styleguide file
+    try:
+        config_file = Config(filename.parent, Path(".wpiformat"))
+    except OSError:
+        config_file = Config(filename.parent, Path(".styleguide"))
+
     if verbose1 or verbose2:
         with print_lock:
-            print("Processing", name)
+            print("Processing", filename)
             if verbose2:
-                print("  with config " + config_file.file_name)
+                print(f"  with config {config_file.filename}")
                 for subtask in task_pipeline:
-                    if subtask.should_process_file(config_file, name):
+                    if subtask.should_process_file(config_file, filename):
                         print("  with " + type(subtask).__name__)
 
-    lines = ""
-    with open(name, "r", encoding="utf8") as file:
-        try:
-            lines = file.read()
-        except UnicodeDecodeError:
-            print(
-                f"error: {name} contains characters not in UTF-8. Should this be considered a generated file?"
-            )
-            return False
+    try:
+        lines = filename.read_text(encoding="utf-8")
+    except UnicodeDecodeError:
+        print(
+            f"error: {filename} contains characters not in UTF-8. Should this be considered a generated file?"
+        )
+        return False
 
     # The success flag is aggregated across multiple file processing results
     all_success = True
 
     output = lines
     for subtask in task_pipeline:
-        if subtask.should_process_file(config_file, name):
-            output, success = subtask.run_pipeline(config_file, name, output)
+        if subtask.should_process_file(config_file, filename):
+            output, success = subtask.run_pipeline(config_file, filename, output)
             all_success &= success
 
     if lines != output:
-        with open(name, "wb") as file:
-            file.write(output.encode())
+        filename.write_bytes(output.encode())
 
     return all_success
 
 
-def proc_standalone(name):
+def proc_standalone(filename: Path) -> bool:
     """Runs each task on each file.
 
     Keyword arguments:
-    name -- file name string
+    filename -- filename
     """
-    config_file = Config(os.path.dirname(name), ".styleguide")
+    # TODO: Remove handling for deprecated .styleguide file
+    try:
+        config_file = Config(filename.parent, Path(".wpiformat"))
+    except OSError:
+        config_file = Config(filename.parent, Path(".styleguide"))
+
     if verbose2:
         with print_lock:
-            print("Processing", name)
+            print("Processing", filename)
             for subtask in task_pipeline:
-                if subtask.should_process_file(config_file, name):
+                if subtask.should_process_file(config_file, filename):
                     print("  with " + type(subtask).__name__)
 
     # The success flag is aggregated across multiple file processing results
     all_success = True
 
     for subtask in task_pipeline:
-        if subtask.should_process_file(config_file, name):
-            success = subtask.run_standalone(config_file, name)
+        if subtask.should_process_file(config_file, filename):
+            success = subtask.run_standalone(config_file, filename)
             all_success &= success
 
     return all_success
 
 
-def chunks(l, max_len):
+def chunks(l: list[Path], max_len: int) -> Generator[list[Path], None, None]:
     """Yield successive chunks from l whose content lengths sum to less than
     max_len.
     """
@@ -156,38 +160,43 @@ def chunks(l, max_len):
     size = 0
     for i, arg in enumerate(l):
         out.append(arg)
-        size += len(arg) + len(" ")
-        if i == len(l) - 1 or size + len(l[i + 1]) > max_len:
+        size += len(arg.as_posix()) + len(" ")
+        if i == len(l) - 1 or size + len(l[i + 1].as_posix()) > max_len:
             yield out
             out = []
             size = 0
 
 
-def proc_batch(files):
+def proc_batch(filenames: list[Path]) -> bool:
     """Runs each task in the pipeline on batches of files.
 
     These tasks read and write to the files directly. They are given a list of
     all files at once to avoid spawning too many subprocesses.
 
     Keyword arguments:
-    files -- list of file names
+    filenames -- list of filenames
 
     Returns true if all tasks succeeded.
     """
     all_success = True
 
     for subtask in task_pipeline:
-        work = []
-        for name in files:
-            config_file = Config(os.path.dirname(name), ".styleguide")
-            if subtask.should_process_file(config_file, name):
-                work.append(name)
+        work: list[Path] = []
+        for filename in filenames:
+            # TODO: Remove handling for deprecated .styleguide file
+            try:
+                config_file = Config(filename.parent, Path(".wpiformat"))
+            except OSError:
+                config_file = Config(filename.parent, Path(".styleguide"))
+
+            if subtask.should_process_file(config_file, filename):
+                work.append(filename)
 
         if work:
             # Conservative estimate for max argument length. 32767 is from the
             # Win32 docs for CreateProcessA(), but the limit appears to be lower
             # than that in practice.
-            MAX_WIN32_ARGS_LEN = 32767 * 7 / 8
+            MAX_WIN32_ARGS_LEN = int(32767 * 7 / 8)
 
             for subwork in chunks(work, MAX_WIN32_ARGS_LEN):
                 if verbose1 or verbose2:
@@ -200,13 +209,13 @@ def proc_batch(files):
     return all_success
 
 
-def run_pipeline(task_pipeline, args, files):
+def run_pipeline(task_pipeline, args, filenames: list[Path]):
     """Spawns process pool for proc_pipeline().
 
     Keyword arguments:
     task_pipeline -- task pipeline
     args -- command line arguments from argparse
-    files -- list of file names to process
+    filenames -- list of filenames to process
 
     Calls sys.exit(1) if any task fails.
     """
@@ -224,19 +233,19 @@ def run_pipeline(task_pipeline, args, files):
 
     with mp.Pool(args.jobs, proc_init, init_args) as pool:
         # Start worker processes for task pipeline
-        results = pool.map(proc_pipeline, files)
+        results = pool.map(proc_pipeline, filenames)
 
         if not all(results):
             sys.exit(1)
 
 
-def run_batch(task_pipeline, args, file_batches):
+def run_batch(task_pipeline, args, filename_batches: list[list[Path]]):
     """Spawns process pool for proc_batch().
 
     Keyword arguments:
     task_pipeline -- task pipeline
     args -- command line arguments from argparse
-    file_batches -- list of file names to process
+    filename_batches -- list of batches of filenames to process
 
     Calls sys.exit(1) if any task fails.
     """
@@ -254,19 +263,19 @@ def run_batch(task_pipeline, args, file_batches):
 
     with mp.Pool(args.jobs, proc_init, init_args) as pool:
         # Start worker processes for batch tasks
-        results = pool.map(proc_batch, file_batches)
+        results = pool.map(proc_batch, filename_batches)
 
         if not all(results):
             sys.exit(1)
 
 
-def run_standalone(task_pipeline, args, files):
+def run_standalone(task_pipeline, args, filenames: list[Path]):
     """Spawns process pool for proc_standalone().
 
     Keyword arguments:
     task_pipeline -- task pipeline
     args -- command line arguments from argparse
-    files -- list of file names to process
+    filenames -- list of filenames to process
 
     Calls sys.exit(1) if any task fails.
     """
@@ -284,7 +293,7 @@ def run_standalone(task_pipeline, args, files):
 
     with mp.Pool(args.jobs, proc_init, init_args) as pool:
         # Start worker processes for standalone tasks
-        results = pool.map(proc_standalone, files)
+        results = pool.map(proc_standalone, filenames)
 
         if not all(results):
             sys.exit(1)
@@ -320,6 +329,13 @@ def main():
         action="store_true",
         help="same as -list-all-files, but list only files changed from default branch",
     )
+    parser.add_argument(
+        "-default-branch",
+        dest="default_branch",
+        type=str,
+        default="",
+        help="branch with respect to which changed files list is generated",
+    )
     # mp.Pool() uses WaitForMultipleObjects() to wait for subprocess completion
     # on Windows. WaitForMultipleObjects() cannot wait on more then 64 events at
     # once, and mp uses a few internal events. Therefore, the maximum number of
@@ -379,128 +395,120 @@ def main():
 
     # tidy requires compile_commands.json
     if args.tidy_all or args.tidy_changed:
-        ccloc = os.path.join(args.compile_commands, "compile_commands.json")
-        if not os.path.exists(ccloc):
+        compile_commands_filename = (
+            Path(args.compile_commands) / "compile_commands.json"
+        )
+        if not compile_commands_filename.exists():
             print(
-                f"error: clang-tidy: {ccloc} not found (try -compile-commands)",
+                f"error: clang-tidy: {compile_commands_filename} not found (try -compile-commands)",
                 file=sys.stderr,
             )
             sys.exit(1)
 
-    # All discovered files are relative to Git repo root directory, so find the
-    # root.
-    root_path = Task.get_repo_root()
-    if root_path == "":
-        print("error: not invoked within a Git repository", file=sys.stderr)
-        sys.exit(1)
+    # Find Git repo root directory that all discovered files are relative to
+    repo_root = Task.get_repo_root()
 
     # If no files explicitly specified
     if not args.file:
-        # Delete temporary files from previous incomplete run
-        files = [
-            os.path.join(dp, f)
-            for dp, dn, fn in os.walk(root_path)
-            for f in fn
-            if f.endswith(".tmp")
-        ]
-        for f in files:
-            os.remove(f)
-
         # Recursively create list of files in given directory
-        files = [os.path.join(dp, f) for dp, dn, fn in os.walk(root_path) for f in fn]
+        filenames: list[Path] = [f for f in repo_root.rglob("*") if f.is_file()]
 
-        if not files:
+        if not filenames:
             print("error: no files found to format", file=sys.stderr)
             sys.exit(1)
     else:
-        files = []
-        for name in args.file:
+        filenames: list[Path] = []
+        for elem in args.file:
             # If a directory was specified, recursively expand it
-            if os.path.isdir(name):
-                files.extend(
-                    [os.path.join(dp, f) for dp, dn, fn in os.walk(name) for f in fn]
-                )
+            if (path := Path(elem)).is_dir():
+                filenames.extend([f for f in path.rglob("*") if f.is_file()])
             else:
-                files.append(name)
+                filenames.append(path)
 
-    # Convert relative paths of files to absolute paths
-    files = [os.path.abspath(name) for name in files]
+    # Convert relative filepaths to absolute
+    filenames: list[Path] = [f.resolve() for f in filenames]
 
-    # Don't run tasks on Git metadata
-    files = [name for name in files if os.sep + ".git" + os.sep not in name]
+    # Skip Git metadata
+    filenames: list[Path] = [f for f in filenames if ".git" not in f.parts]
 
-    # Don't check for changes in or run tasks on ignored files
-    files = filter_ignored_files(files)
+    # Skip ignored files
+    filenames: list[Path] = filter_for_unignored_files(filenames)
 
     # Throw an error if any files or directories don't exist
-    for f in files:
-        if not os.path.exists(f):
-            if not os.path.islink(f):
+    for f in filenames:
+        if not f.exists():
+            if not f.is_symlink():
                 print(f"error: {f}: No such file or directory")
                 sys.exit(1)
             else:
                 print(f"warning: {f}: Broken symlink")
 
     # Determine name of default branch for generated file comparisons
-    branch_options = ["origin/HEAD", "main", "master"]
-    default_branch = ""
-    for branch in branch_options:
-        proc = subprocess.run(
-            ["git", "rev-parse", "-q", "--verify", branch], stdout=subprocess.DEVNULL
-        )
-        if proc.returncode == 0:
-            default_branch = branch
-            break
-
-    if not default_branch:
-        print(
-            f"error: One of the following branches is required for generated file comparisons, but none exist: {branch_options}."
-        )
-        sys.exit(1)
+    if not (default_branch := args.default_branch):
+        branch_options = ["origin/HEAD", "main", "master"]
+        for branch in branch_options:
+            proc = subprocess.run(
+                ["git", "rev-parse", "-q", "--verify", branch],
+                stdout=subprocess.DEVNULL,
+            )
+            if proc.returncode == 0:
+                default_branch = branch
+                break
+        if not default_branch:
+            print(
+                f"error: no default branch provided, and none of the following default branches exist: {branch_options}."
+            )
+            sys.exit(1)
 
     # Create list of all changed files
-    changed_file_list = [
-        root_path + os.sep + os.path.normpath(line.rstrip())
+    changed_file_list: list[Path] = [
+        (repo_root / line.rstrip()).resolve()
         for line in subprocess.check_output(
             ["git", "diff", "--name-only", f"{default_branch}..."], encoding="ascii"
         ).split()
     ]
 
-    # Don't run tasks on modifiable or generated files
-    work = []
-    for name in files:
-        config_file = Config(os.path.dirname(name), ".styleguide")
+    # Skip modifiable or generated files
+    work: list[Path] = []
+    for filename in filenames:
+        # TODO: Remove handling for deprecated .styleguide file
+        try:
+            config_file = Config(filename.parent, Path(".wpiformat"))
+        except OSError:
+            config_file = Config(filename.parent, Path(".styleguide"))
 
-        if config_file.is_modifiable_file(name):
+        if config_file.is_modifiable_file(filename):
             continue
-        if config_file.is_generated_file(name):
+        if config_file.is_generated_file(filename):
             # Emit warning if a generated file was editted
             if (
-                name in changed_file_list
+                filename in changed_file_list
                 and not args.list_all_files
                 and not args.list_changed_files
             ):
-                print("warning: generated file '" + name + "' modified")
+                print(f"warning: generated file '{filename}' modified")
             continue
 
-        work.append(name)
-    files = work
+        work.append(filename)
+    filenames = work
 
     # If there are no files left, do nothing
-    if len(files) == 0:
+    if len(filenames) == 0:
         sys.exit(0)
 
     # Handle list-all-files and list-changed-files options
     if args.list_all_files or args.list_changed_files:
         if args.list_changed_files:
-            files = list(set(files) & set(changed_file_list))
-        for file in files:
-            print(file)
+            filenames = list(set(filenames) & set(changed_file_list))
+        for f in filenames:
+            print(f)
         sys.exit(0)
 
     # Prepare file batches for batch tasks
-    chunksize = math.ceil(len(files) / args.jobs)
-    file_batches = [files[i : i + chunksize] for i in range(0, len(files), chunksize)]
+    chunksize = math.ceil(len(filenames) / args.jobs)
+    file_batches = [
+        filenames[i : i + chunksize] for i in range(0, len(filenames), chunksize)
+    ]
 
     if args.no_format:
         # Only run Lint
@@ -523,7 +531,7 @@ def main():
             ClangFormat(),
             Jni(),  # Fixes clang-format formatting
         ]
-        run_pipeline(task_pipeline, args, files)
+        run_pipeline(task_pipeline, args, filenames)
 
         # Lint is run last since previous tasks can affect its output.
         task_pipeline = [CMakeFormat(), PyFormat(), Lint()]
@@ -533,14 +541,14 @@ def main():
     # ClangTidy is run last of all; it needs the actual files
     if args.tidy_all or args.tidy_changed:
         if args.tidy_changed:
-            files = list(set(files) & set(changed_file_list))
+            filenames = list(set(filenames) & set(changed_file_list))
         task_pipeline = [
             ClangTidy(
                 args.compile_commands,
                 args.tidy_extra_args.split(",") if args.tidy_extra_args else [],
             )
         ]
-        run_standalone(task_pipeline, args, files)
+        run_standalone(task_pipeline, args, filenames)
 
 
 if __name__ == "__main__":
