@@ -1,25 +1,27 @@
 """This task replaces empty C identifier lists "()" with "(void)"."""
 
-import regex
+import re
+from pathlib import Path
 
+from wpiformat.config import Config
 from wpiformat.task import PipelineTask
 
 
 class CIdentList(PipelineTask):
     @staticmethod
-    def __print_failure(name):
+    def __print_failure(filename):
         print(
-            "error: " + name + ": unmatched curly braces when scanning for "
-            "C identifier lists. If the code compiles, this is a bug in "
+            f"error: {filename}: unmatched curly braces when scanning for C "
+            "identifier lists. If the code compiles, this is a bug in "
             "wpiformat."
         )
 
     @staticmethod
-    def should_process_file(config_file, name):
-        return config_file.is_c_file(name) or config_file.is_cpp_file(name)
+    def should_process_file(config_file: Config, filename: Path) -> bool:
+        return config_file.is_c_file(filename) or config_file.is_cpp_file(filename)
 
     @staticmethod
-    def is_quote_in_number(lines, i):
+    def is_quote_in_number(lines: str, i: int) -> bool:
         if i == 0:
             return False
         c = lines[i - 1]
@@ -29,14 +31,16 @@ class CIdentList(PipelineTask):
             or ord("a") <= ord(c) <= ord("f")
         )
 
-    def run_pipeline(self, config_file, name, lines):
+    def run_pipeline(
+        self, config_file: Config, filename: Path, lines: str
+    ) -> tuple[str, bool]:
         linesep = super().get_linesep(lines)
 
         output = ""
         pos = 0
 
         # C files use C linkage by default
-        is_c = config_file.is_c_file(name)
+        is_c: int = 1 if config_file.is_c_file(filename) else 0
 
         # Tokenize as extern "C" or extern "C++" with optional {, open brace,
         # close brace, or () folllowed by { to disambiguate function calls.
@@ -60,7 +64,7 @@ class CIdentList(PipelineTask):
         extern_str = r"(?P<ext_decl>extern \"C(\+\+)?\")\s+(?P<ext_brace>\{)?|"
         braces_str = r"\{|\}|;|def\s+\w+|\w+\**\s+\w+\s*(?P<paren>\(\))"
         postfix_str = r"(?=\s*(;|\{))"
-        token_regex = regex.compile(
+        token_regex = re.compile(
             preproc_str
             + comment_str
             + string_str
@@ -140,7 +144,7 @@ class CIdentList(PipelineTask):
                 is_c = extern_brace_indices.pop()
 
                 if len(extern_brace_indices) == 0:
-                    self.__print_failure(name)
+                    self.__print_failure(filename)
                     return lines, False
 
                 # If the next stack frame is from an extern without braces, pop
@@ -150,7 +154,7 @@ class CIdentList(PipelineTask):
                     extern_brace_indices.pop()
             elif token == ";":
                 if len(extern_brace_indices) == 0:
-                    self.__print_failure(name)
+                    self.__print_failure(filename)
                     return lines, False
 
                 # If the next stack frame is from an extern without braces, pop
@@ -187,6 +191,6 @@ class CIdentList(PipelineTask):
         # Invariant: extern_brace_indices has one entry
         success = len(extern_brace_indices) == 1
         if not success:
-            self.__print_failure(name)
+            self.__print_failure(filename)
 
         return output, success
