@@ -1,10 +1,12 @@
 """This task runs clang-format on the file."""
 
+import subprocess
 import sys
-from subprocess import PIPE, Popen
+from pathlib import Path
 
 import clang_format
 
+from wpiformat.config import Config
 from wpiformat.task import PipelineTask
 
 
@@ -16,15 +18,17 @@ class ClangFormat(PipelineTask):
         self.exec_name = clang_format.get_executable("clang-format")
 
     @staticmethod
-    def should_process_file(config_file, name):
-        return config_file.is_c_file(name) or config_file.is_cpp_file(name)
+    def should_process_file(config_file: Config, filename: Path) -> bool:
+        return config_file.is_c_file(filename) or config_file.is_cpp_file(filename)
 
-    def run_pipeline(self, config_file, name, lines):
+    def run_pipeline(
+        self, config_file: Config, filename: Path, lines: str
+    ) -> tuple[str, bool]:
         try:
-            p = Popen(
-                [self.exec_name, "-style=file", "-assume-filename=" + name, "-"],
-                stdin=PIPE,
-                stdout=PIPE,
+            p = subprocess.Popen(
+                [self.exec_name, "-style=file", f"-assume-filename={filename}", "-"],
+                stdin=subprocess.PIPE,
+                stdout=subprocess.PIPE,
                 encoding="utf-8",
             )
             stdout, stderr = p.communicate(input=lines)
