@@ -2,21 +2,25 @@
 "TEST(ThingTest, Thing)".
 """
 
-import regex
+import re
+from pathlib import Path
 
+from wpiformat.config import Config
 from wpiformat.task import PipelineTask
 
 
 class GTestName(PipelineTask):
     @staticmethod
-    def should_process_file(config_file, name):
-        return config_file.is_cpp_file(name)
+    def should_process_file(config_file: Config, filename: Path) -> bool:
+        return config_file.is_cpp_file(filename)
 
-    def run_pipeline(self, config_file, name, lines):
+    def run_pipeline(
+        self, config_file: Config, filename: Path, lines: str
+    ) -> tuple[str, bool]:
         output = ""
         success = True
 
-        test_name_rgx = regex.compile(
+        test_name_rgx = re.compile(
             r"\b(?P<test_type>TEST(_F|_P)?)\((?P<whitespace>\s*)(?P<test_suite>\w+), (?P<test_case>\w+)\)"
         )
         extract_location = 0
@@ -45,7 +49,7 @@ class GTestName(PipelineTask):
             # Fix test case name
             if test_case == "Test" or test_case == "Tests":
                 print(
-                    f"error: {name}: undescriptive test case name '{test_case}' in '{test_suite}.{test_case}'"
+                    f"error: {filename}: undescriptive test case name '{test_case}' in '{test_suite}.{test_case}'"
                 )
                 success = False
             else:
@@ -67,7 +71,7 @@ class GTestName(PipelineTask):
         lines = output
         output = ""
 
-        inst_rgx = regex.compile(
+        inst_rgx = re.compile(
             r"INSTANTIATE_TEST_SUITE_P\((?P<whitespace>\s*)(?P<test_suite>\w+), (?P<test_case>\w+)"
         )
         extract_location = 0
