@@ -2,11 +2,11 @@
 style guide.
 """
 
-import os
+import re
 from enum import Enum
+from pathlib import Path
 
-import regex
-
+from wpiformat.config import Config
 from wpiformat.task import PipelineTask
 
 
@@ -18,17 +18,19 @@ class State(Enum):
 
 class IncludeGuard(PipelineTask):
     @staticmethod
-    def should_process_file(config_file, name):
-        return config_file.is_header_file(name)
+    def should_process_file(config_file: Config, filename: Path):
+        return config_file.is_header_file(filename)
 
-    def run_pipeline(self, config_file, name, lines):
+    def run_pipeline(
+        self, config_file: Config, filename: Path, lines: str
+    ) -> tuple[str, bool]:
         linesep = super().get_linesep(lines)
         lines_list = lines.split(linesep)
         output_list = lines_list
 
         state = State.FINDING_IFNDEF
-        ifndef_regex = regex.compile(r"#ifndef \w+", regex.ASCII)
-        define_regex = regex.compile(r"#define \w+", regex.ASCII)
+        ifndef_regex = re.compile(r"#ifndef \w+", re.ASCII)
+        define_regex = re.compile(r"#define \w+", re.ASCII)
 
         if_preproc_count = 0
         for i in range(len(lines_list)):
@@ -38,7 +40,7 @@ class IncludeGuard(PipelineTask):
                 ].lstrip().startswith("#define "):
                     state = State.FINDING_ENDIF
 
-                    guard = self.make_include_guard(config_file, name)
+                    guard = self.make_include_guard(config_file, filename)
                     output_list[i] = ifndef_regex.sub("#ifndef " + guard, lines_list[i])
                     output_list[i + 1] = define_regex.sub(
                         "#define " + guard, lines_list[i + 1]
@@ -62,44 +64,34 @@ class IncludeGuard(PipelineTask):
 
         # If include guard not found
         if state == State.FINDING_IFNDEF:
-            print(
-                "error: " + name + ": doesn't contain include guard or '#pragma once'"
-            )
+            print(f"error: {filename}: doesn't contain include guard or '#pragma once'")
             return lines, False
 
         output = linesep.join(output_list).rstrip() + linesep
         return output, True
 
-    def make_include_guard(self, config_file, name):
+    def make_include_guard(self, config_file: Config, filename: Path) -> str:
         """Returns properly formatted include guard based on repository root and
-        file name.
+        filename.
 
         Keyword arguments:
         config_file -- Config object
-        name -- file name string
+        filename -- filename
         """
-        repo_root_name_override = config_file.group("repoRootNameOverride")
-
         repo_root = super().get_repo_root()
-        guard_root = os.path.relpath(name, repo_root)
-        if not repo_root_name_override:
-            guard_path = os.path.basename(repo_root) + os.sep
+
+        if repo_root_override := config_file.group("repoRootNameOverride"):
+            guard_path = repo_root_override[0] + "/"
         else:
-            guard_path = repo_root_name_override[0] + os.sep
-        include_roots = config_file.group("includeGuardRoots")
+            guard_path = repo_root.name + "/"
 
-        if include_roots:
-            prefix = ""
-            for include_root in include_roots:
-                if guard_root.startswith(include_root) and len(include_root) > len(
-                    prefix
-                ):
-                    prefix = include_root
-            guard_path += guard_root[len(prefix) :]
-            return (regex.sub(r"[^a-zA-Z0-9]", "_", guard_path).upper() + "_").lstrip(
-                "_"
-            )
+        # Use include root that results in shortest include guard
+        guard_root = filename.relative_to(repo_root).as_posix()
+        for include_root in sorted(
+            config_file.group("includeGuardRoots"), key=len, reverse=True
+        ):
+            if guard_root.startswith(include_root):
+                guard_path += guard_root[len(include_root) :]
+                break
 
-        # No include guard roots matched, so append full name
-        guard_path += guard_root
-        return regex.sub(r"[^a-zA-Z0-9]", "_", guard_path).upper() + "_"
+        return re.sub(r"[^a-zA-Z0-9]", "_", guard_path).upper().lstrip("_") + "_"
